# Toutatis
![PyPI](https://img.shields.io/pypi/v/toutatis) ![PyPI - Week](https://img.shields.io/pypi/dw/toutatis) ![PyPI - Downloads](https://static.pepy.tech/badge/toutatis) ![PyPI - License](https://img.shields.io/pypi/l/toutatis)
#### For BTC Donations : 1FHDM49QfZX6pJmhjLE5tB2K6CaTLMZpXZ
## Educational purposes only
Toutatis is a tool that allows you to extract information from instagrams accounts such as e-mails, phone numbers and more


## 💡 Prerequisite
 [Python](https://www.python.org/downloads/release/python-370/)

## 🛠️ Installation
### With PyPI
 ```pip3 install holehe
 ```
### With Github
```bash
git clone https://github.com/megadose/toutatis.git
cd toutatis/
python3 setup.py install
```
## 📈 Usage
toutatis [-h] -u USERNAME -s SESSIONID
```
## 📚 To retrieve the sessionID
![](https://files.catbox.moe/1rfi6j.png)
## 📝 License
[GNU General Public License v3.0](https://www.gnu.org/licenses/gpl-3.0.fr.html)
